use argh::FromArgs;

use crate::api::qbittorrent::{ApiClient, RawApiClient};
use crate::Error;
use crate::action::ActionExec;
use crate::config::Config;

#[derive(FromArgs, PartialEq, Debug)]
#[argh(subcommand, name = "list")]
/// list existing torrents on qBittorrent
pub struct ListAction {
    #[argh(switch, short = 'r')]
    /// return raw JSON response from API
    raw: bool,
}

impl ActionExec for ListAction {
    fn exec(&self, config: &Config) -> Result<(), Error> {
        if self.raw {
            let api = RawApiClient::from_config(&config)?;
            println!("{}", api.list()?);
        } else {
            let api = ApiClient::from_config(&config)?;
            for torrent in api.list()? {
                println!("{}", torrent.hash);
            }
        }
        Ok(())
    }
}
