pub mod qbittorrent;

pub fn calc_progress(have: f64, total: f64) -> u8 {
    let ratio = have / total * f64::from(100);
    ratio.floor() as u8
}

pub trait IntoTorrent {
    fn into_torrent(&self, hash: &str) -> Torrent;
}

#[derive(Clone, Serialize, Deserialize)]
pub struct Torrent {
    pub hash: String,
    pub name: String,
    pub path: String,
    pub date_start: i64,
    pub date_end: i64,
    /// Progress percentage (0-100)
    pub progress: u8,
    pub size: i64,
}

#[derive(Clone, Serialize, Deserialize)]
pub struct TorrentList(Vec<Torrent>);

impl TorrentList {
    pub fn new() -> TorrentList {
        TorrentList(Vec::new())
    }

    pub fn push(&mut self, entry: Torrent) {
        self.0.push(entry);
    }
}

impl IntoIterator for TorrentList {
    type Item = Torrent;
    type IntoIter = std::vec::IntoIter<Self::Item>;

    fn into_iter(self) -> Self::IntoIter {
        self.0.into_iter()
    }
}

impl FromIterator<Torrent> for TorrentList {
    fn from_iter<I: IntoIterator<Item=Torrent>>(iter: I) -> Self {
        let mut c = TorrentList::new();

        for i in iter {
            c.push(i);
        }

        c
    }
}
